<?php
// namespace MasterMegaMenu;

defined( 'ABSPATH' ) || exit;

if( !class_exists('Master_Mega_Menu') ){
	class Master_Mega_Menu{

		public $dir;
		
		public $url;

		private static $plugin_path;

	    private static $plugin_url;

	    private static $_instance = null;

	    const VERSION = "1.0.0";

	    const MINIMUM_PHP_VERSION = '5.4';
	    
	    const MINIMUM_ELEMENTOR_VERSION = '2.0.0';

		private static $plugin_name = 'Master Mega Menu';	    
			
	    public function __construct(){
			
			$this->jltma_constants();

	        // Current Path
	        $this->dir = dirname(__FILE__) . '/';

			$this->url = self::plugin_url() . '/master-mega-menu/';		

			// Include Files
			$this->jltma_include_files();

			add_action('plugins_loaded', [$this, 'jltma_megamenu_plugins_loaded']);

			// Widget Register
			add_action( 'elementor/widgets/widgets_registered', [ $this, 'jltma_megamenu_init_widgets' ] );
			
			//Register Controls
			add_action( 'elementor/controls/controls_registered'   , array( $this, 'jltma_register_controls' ) );

			jltma_megamenu_assets();
	        jltma_megamenu_options();

	        jltma_megamenu_api()->init();
	        jltma_megamenu_cpt_api()->init();
			
	        if ( is_admin() ) {        	
	        	jltma_megamenu_cpt();
	        }
		}



		// Initialize
		public function jltma_megamenu_plugins_loaded(){

			// Check if Elementor installed and activated
			if ( ! did_action( 'elementor/loaded' ) ) {
				add_action( 'admin_notices', array( $this, 'jltma_megamenu_notice_missing_main_plugin' ) );
				return;
			}

			// Check for required Elementor version
			if ( ! version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
				add_action( 'admin_notices', array( $this, 'jltma_megamenu_notice_minimum_elementor_version' ) );
				return;
			}

			// Check for required PHP version
			if ( version_compare( PHP_VERSION, self::MINIMUM_PHP_VERSION, '<' ) ) {
				add_action( 'admin_notices', array( $this, 'jltma_megamenu_notice_minimum_php_version' ) );
				return;
			}

		}


	    public function is_elementor_activated( $plugin_path = 'elementor/elementor.php' ){
	        $installed_plugins_list = get_plugins();
	        return isset( $installed_plugins_list[ $plugin_path ] );
	    }


		public function jltma_megamenu_notice_missing_main_plugin() {
			$plugin = 'elementor/elementor.php';

			if ( $this->is_elementor_activated() ) {
				if ( ! current_user_can( 'activate_plugins' ) ) {
					return;
				}
				$activation_url = wp_nonce_url( 'plugins.php?action=activate&amp;plugin=' . $plugin . '&amp;plugin_status=all&amp;paged=1&amp;s', 'activate-plugin_' . $plugin );
				// $message = esc_html__( 'Master Mega Menu requires <b>', 'jltma' );
				$message = sprintf( esc_html__( 'Master Mega Menu requires %1$s"Elementor"%2$s plugin to be active. Please activate Elementor to continue.', 'jltma' ), '<strong>', '</strong>' );
				$button_text = esc_html__( 'Activate Elementor', 'jltma' );

			} else {
				if ( ! current_user_can( 'install_plugins' ) ) {
					return;
				}

				$activation_url = wp_nonce_url( self_admin_url( 'update.php?action=install-plugin&plugin=elementor' ), 'install-plugin_elementor' );
				$message = sprintf( esc_html__( 'Master Mega Menu requires %1$s"Elementor"%2$s plugin to be installed and activated. Please install Elementor to continue.', 'jltma' ), '<strong>', '</strong>' );
				$button_text = esc_html__( 'Install Elementor', 'jltma' );
			}




			$button = '<p><a href="' . esc_url_raw( $activation_url ) . '" class="button-primary">' . esc_html( $button_text ) . '</a></p>';

			printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p>%2$s</div>', $message , $button );

		}


		public function jltma_megamenu_notice_minimum_elementor_version() {
			if ( isset( $_GET['activate'] ) ) {
				unset( $_GET['activate'] );
			}

			$message = sprintf(
			/* translators: 1: Plugin name 2: Elementor 3: Required Elementor version */
				esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'jltma' ),
				'<strong>' . esc_html__( 'Master Addons for Elementor', 'jltma' ) . '</strong>',
				'<strong>' . esc_html__( 'Elementor', 'jltma' ) . '</strong>',
				self::MINIMUM_ELEMENTOR_VERSION
			);

			printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
		}

		public function jltma_megamenu_notice_minimum_php_version() {
			if ( isset( $_GET['activate'] ) ) {
				unset( $_GET['activate'] );
			}

			$message = sprintf(
			/* translators: 1: Plugin name 2: PHP 3: Required PHP version */
				esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'jltma' ),
				'<strong>' . esc_html__( 'Master Addons for Elementor', 'jltma' ) . '</strong>',
				'<strong>' . esc_html__( 'PHP', 'jltma' ) . '</strong>',
				self::MINIMUM_PHP_VERSION
			);

			printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
		}

		public function jltma_constants(){

			//Defined Constants

			if ( ! defined( 'JLTMA' ) ) {
				define( 'JLTMA', self::$plugin_name );
			}

			if (!defined('JLTMA_BADGE')) {
				define( 'JLTMA_BADGE', '<span class="ma-el-badge"></span>' );
			}

			if ( ! defined( 'JLTMA_VERSION' ) ) {
				define( 'JLTMA_VERSION', self::version() );
			}

			if ( ! defined( 'JLTMA_PLUGIN_URL' ) ) {
				define( 'JLTMA_PLUGIN_URL', self::plugin_url() );
			}

			if ( ! defined( 'JLTMA_PLUGIN_PATH' ) ) {
				define( 'JLTMA_PLUGIN_PATH', self::plugin_path() );
			}

			if ( ! defined( 'JLTMA_ADDON' ) ) {
				define( 'JLTMA_ADDON', plugin_dir_path( __FILE__ ) . 'addon/' );
			}

			// Master Addons Text Domain
			if ( ! defined( 'JLTMA_TD' ) ) {
				define( 'JLTMA_TD', $this->jltma_load_textdomain() );
			}

			if ( ! defined( 'JLTMA_FILE' ) ) {
				define( 'JLTMA_FILE', __FILE__ );
			}

			if ( ! defined( 'JLTMA_DIR' ) ) {
				define( 'JLTMA_DIR', dirname( __FILE__ ) );
			}
		}


		public function jltma_megamenu_init_widgets() {

			//Master Mega Menu Navigation Addon
			require_once JLTMA_ADDON . 'master-navigation.php';
		}


		public function jltma_register_controls($controls_manager){

			$controls_manager = \Elementor\Plugin::$instance->controls_manager;

			$controls = array(
				'jltma-visual-select' => array(
					'file'  => JLTMA_PLUGIN_PATH . '/inc/controls/visual-select.php',
					'class' => 'Master_Megamenu\Inc\Controls\JLTMA_Control_Visual_Select',
					'type'  => 'single'
				)
			);

			foreach ( $controls as $control_type => $control_info ) {
				if( ! empty( $control_info['file'] ) && ! empty( $control_info['class'] ) ){

					include_once( $control_info['file'] );

					if( class_exists( $control_info['class'] ) ){
						$class_name = $control_info['class'];
					} elseif( class_exists( __NAMESPACE__ . '\\' . $control_info['class'] ) ){
						$class_name = __NAMESPACE__ . '\\' . $control_info['class'];
					}

					if( $control_info['type'] === 'group' ){
						$controls_manager->add_group_control( $control_type, new $class_name() );
					} else {
						$controls_manager->register_control( $control_type, new $class_name() );
					}

				}
			}

		}


		public function jltma_load_textdomain(){
			load_plugin_textdomain( 'jltma' );
		}


		public static function version() {
			return self::VERSION;
		}

		public function jltma_include_files(){
	        include JLTMA_PLUGIN_PATH . '/inc/cpt.php';
			include JLTMA_PLUGIN_PATH . '/inc/megamenu-assets.php';
			include JLTMA_PLUGIN_PATH . '/inc/rest-api.php';
	        include JLTMA_PLUGIN_PATH . '/inc/api.php';		
			include JLTMA_PLUGIN_PATH . '/inc/options.php';
			include JLTMA_PLUGIN_PATH . '/inc/walker-nav-menu.php';
			include JLTMA_PLUGIN_PATH . '/inc/cpt-api.php';
		}


	    public static function plugin_url() {
	        if ( self::$plugin_url ) {
	            return self::$plugin_url;
	        }
	        return self::$plugin_url = untrailingslashit( plugins_url( '/', __FILE__ ) );
	    }

	    public static function plugin_path() {
	        if ( self::$plugin_path ) {
	            return self::$plugin_path;
	        }
	        return self::$plugin_path = untrailingslashit( plugin_dir_path( __FILE__ ) );
	    }

	    public static function get_instance() {
	        if ( is_null( self::$_instance ) ) {
	            self::$_instance = new self();
	        }
	        return self::$_instance;
	    }
	}
}

/*
* Returns Instanse of the Master Mega Menu
*/
if( !function_exists('jltma_megamenu')){
    function jltma_megamenu(){
        return  Master_Mega_Menu::get_instance();
    }
}

jltma_megamenu();

/* Re-write flus */
register_activation_hook  ( __FILE__, 'jltma_flush_rewrites' );
register_deactivation_hook( __FILE__, 'jltma_flush_rewrites' );
if( !function_exists('jltma_flush_rewrites')){
    function jltma_flush_rewrites() {
        flush_rewrite_rules();
    }
}